@@ -42,8 +42,9 @@ eos
         is_expected.to contain_class('tripleo::profile::base::nova')
         is_expected.to_not contain_class('nova::keystone::authtoken')
         is_expected.to_not contain_class('nova::api')
-        is_expected.to_not contain_class('nova::wsgi::apache_api')
+        is_expected.to_not contain_class('nova::cors')
         is_expected.to_not contain_class('nova::network::neutron')
+        is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
     end
 
@@ -59,8 +60,9 @@ eos
         is_expected.to contain_class('nova::cell_v2::simple_setup')
         is_expected.to contain_class('nova::keystone::authtoken')
         is_expected.to contain_class('nova::api')
-        is_expected.to_not contain_class('nova::wsgi::apache_api')
+        is_expected.to contain_class('nova::cors')
         is_expected.to contain_class('nova::network::neutron')
+        is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
     end
 
@@ -76,8 +78,9 @@ eos
         is_expected.to contain_class('nova::cell_v2::simple_setup')
         is_expected.to contain_class('nova::keystone::authtoken')
         is_expected.to contain_class('nova::api')
-        is_expected.to_not contain_class('nova::wsgi::apache_api')
+        is_expected.to contain_class('nova::cors')
         is_expected.to contain_class('nova::network::neutron')
+        is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
     end
 
@@ -91,8 +94,9 @@ eos
         is_expected.to_not contain_class('nova::db::sync_cell_v2')
         is_expected.to contain_class('nova::keystone::authtoken')
         is_expected.to contain_class('nova::api')
-        is_expected.to_not contain_class('nova::wsgi::apache_api')
+        is_expected.to contain_class('nova::cors')
         is_expected.to contain_class('nova::network::neutron')
+        is_expected.to_not contain_class('nova::wsgi::apache_api')
       }
     end
 
@@ -109,8 +113,9 @@ eos
         is_expected.to_not contain_class('nova::db::sync_cell_v2')
         is_expected.to contain_class('nova::keystone::authtoken')
         is_expected.to contain_class('nova::api')
-        is_expected.to contain_class('nova::wsgi::apache_api')
+        is_expected.to contain_class('nova::cors')
         is_expected.to contain_class('nova::network::neutron')
+        is_expected.to contain_class('nova::wsgi::apache_api')
       }
     end
 
